@@ -19,15 +19,24 @@
 
 
 --
--- KULRICE-10251: Maintain KRMS Agenda permission has confusing and unused permission detail
+-- KULRICE-6842: Don't allow requests for null principals or null groups or null principal types
+-- or null roles.
 --
 
-DELETE FROM krim_perm_attr_data_t
-WHERE attr_val = 'KRMS_TEST' AND perm_id =
-  (
-    SELECT
-      perm_id
-    FROM krim_perm_t
-    WHERE nm = 'Maintain KRMS Agenda' AND nmspc_cd = 'KR-RULE-TEST'
-  );
+ALTER TABLE
+  KRIM_GRP_MBR_T
+MODIFY
+   (
+    MBR_ID VARCHAR2(40) NOT NULL,
+    GRP_ID VARCHAR2(40) NOT NULL,
+    MBR_TYP_CD CHAR(1) NOT NULL
+   );
 
+ALTER TABLE
+   KRIM_ROLE_MBR_T
+MODIFY
+   (
+    MBR_ID VARCHAR2(40) NOT NULL,
+    ROLE_ID VARCHAR2(40) NOT NULL,
+    MBR_TYP_CD CHAR(1) NOT NULL
+   );
